==> ejc-probid-api-3.0.0-20220715.084523-9-sources.jar: com/ejianc/business/review/vo/ReviewVO.java <==
package com.ejianc.business.review.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 投标文件评审实体
 *
 * @author generator
 */
public class ReviewVO extends BaseVO {
	private static final long serialVersionUID = -171648246389315329L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private Date registrationDeadline; // 报名截止日期
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String detailedAddress; // 工程地点(详细地址)
	private String telFax; // 电话传真
	private BigDecimal bidPrice; // 投标报价
	private Long structureId; // 结构id
	private String structureCode; // 结构编码
	private String structureName; // 结构名称
	private BigDecimal projectTotalArea; // 建筑面积
	private Long contractModeId; // 承包形式id
	private String contractModeCode; // 承包形式编码
	private String contractModeName; // 承包形式名称
	private Long projectQualityId; // 工程质量id
	private String projectQualityCode; // 工程质量编码
	private String projectQualityName; // 工程质量名称
	private Integer projectDuration; // 工期
	private Date handleDate; // 办理日期
	private Long sourceBidRecordId; // 工程投标备案id
	private String projectContentId; // 工程内容id
	private String projectContentCode; // 工程内容code
	private String projectContentName; // 工程内容name
	private Integer bidFlag; // 是否投标 0-否，1-是
	private String memo; // 其他说明

	private List<ReviewFundVO> reviewFundList = new ArrayList<>(); // 投标文件评审-资金情况实体
	private List<ReviewContentVO> reviewContentList = new ArrayList<>(); // 投标文件评审-评审内容实体

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getDetailedAddress() {
		return detailedAddress;
	}

	public void setDetailedAddress(String detailedAddress) {
		this.detailedAddress = detailedAddress;
	}

	public String getTelFax() {
		return telFax;
	}

	public void setTelFax(String telFax) {
		this.telFax = telFax;
	}

	public BigDecimal getBidPrice() {
		return bidPrice;
	}

	public void setBidPrice(BigDecimal bidPrice) {
		this.bidPrice = bidPrice;
	}

	public Long getStructureId() {
		return structureId;
	}

	public void setStructureId(Long structureId) {
		this.structureId = structureId;
	}

	public String getStructureCode() {
		return structureCode;
	}

	public void setStructureCode(String structureCode) {
		this.structureCode = structureCode;
	}

	public String getStructureName() {
		return structureName;
	}

	public void setStructureName(String structureName) {
		this.structureName = structureName;
	}

	public BigDecimal getProjectTotalArea() {
		return projectTotalArea;
	}

	public void setProjectTotalArea(BigDecimal projectTotalArea) {
		this.projectTotalArea = projectTotalArea;
	}

	public Long getContractModeId() {
		return contractModeId;
	}

	public void setContractModeId(Long contractModeId) {
		this.contractModeId = contractModeId;
	}

	public String getContractModeCode() {
		return contractModeCode;
	}

	public void setContractModeCode(String contractModeCode) {
		this.contractModeCode = contractModeCode;
	}

	public String getContractModeName() {
		return contractModeName;
	}

	public void setContractModeName(String contractModeName) {
		this.contractModeName = contractModeName;
	}

	public Long getProjectQualityId() {
		return projectQualityId;
	}

	public void setProjectQualityId(Long projectQualityId) {
		this.projectQualityId = projectQualityId;
	}

	public String getProjectQualityCode() {
		return projectQualityCode;
	}

	public void setProjectQualityCode(String projectQualityCode) {
		this.projectQualityCode = projectQualityCode;
	}

	public String getProjectQualityName() {
		return projectQualityName;
	}

	public void setProjectQualityName(String projectQualityName) {
		this.projectQualityName = projectQualityName;
	}

	public Integer getProjectDuration() {
		return projectDuration;
	}

	public void setProjectDuration(Integer projectDuration) {
		this.projectDuration = projectDuration;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

	public Long getSourceBidRecordId() {
		return sourceBidRecordId;
	}

	public void setSourceBidRecordId(Long sourceBidRecordId) {
		this.sourceBidRecordId = sourceBidRecordId;
	}

	public String getProjectContentId() {
		return projectContentId;
	}

	public void setProjectContentId(String projectContentId) {
		this.projectContentId = projectContentId;
	}

	public String getProjectContentCode() {
		return projectContentCode;
	}

	public void setProjectContentCode(String projectContentCode) {
		this.projectContentCode = projectContentCode;
	}

	public String getProjectContentName() {
		return projectContentName;
	}

	public void setProjectContentName(String projectContentName) {
		this.projectContentName = projectContentName;
	}

	public Integer getBidFlag() {
		return bidFlag;
	}

	public void setBidFlag(Integer bidFlag) {
		this.bidFlag = bidFlag;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<ReviewFundVO> getReviewFundList() {
		return reviewFundList;
	}

	public void setReviewFundList(List<ReviewFundVO> reviewFundList) {
		this.reviewFundList = reviewFundList;
	}

	public List<ReviewContentVO> getReviewContentList() {
		return reviewContentList;
	}

	public void setReviewContentList(List<ReviewContentVO> reviewContentList) {
		this.reviewContentList = reviewContentList;
	}
}

==> ejc-probid-api-3.0.0-20220728.021911-64-sources.jar: com/ejianc/business/review/vo/ReviewVO.java <==
package com.ejianc.business.review.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 投标文件评审实体
 *
 * @author generator
 */
public class ReviewVO extends BaseVO {
	private static final long serialVersionUID = -9024839672319904514L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date registrationDeadline; // 报名截止日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String detailedAddress; // 工程地点(详细地址)
	private String telFax; // 电话传真
	private BigDecimal bidPrice; // 投标报价
	private Long structureId; // 结构id
	private String structureCode; // 结构编码
	private String structureName; // 结构名称
	private BigDecimal projectTotalArea; // 建筑面积
	private Long contractModeId; // 承包形式id
	private String contractModeCode; // 承包形式编码
	private String contractModeName; // 承包形式名称
	private Long projectQualityId; // 工程质量id
	private String projectQualityCode; // 工程质量编码
	private String projectQualityName; // 工程质量名称
	private Integer projectDuration; // 工期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date handleDate; // 办理日期
	private Long sourceBidRecordId; // 工程投标备案id
	private String projectContentId; // 工程内容id
	private String projectContentCode; // 工程内容code
	private String projectContentName; // 工程内容name
	private Integer bidFlag; // 是否投标 0-否，1-是
	private String memo; // 其他说明

	private List<ReviewFundVO> reviewFundList = new ArrayList<>(); // 投标文件评审-资金情况实体
	private List<ReviewContentManageVO> reviewContentManageList = new ArrayList<>(); // 投标文件评审-评审内容-经营负责人实体
	private List<ReviewContentTechnologyVO> reviewContentTechnologyList = new ArrayList<>(); // 投标文件评审-评审内容-技术负责人实体
	private List<ReviewContentBudgetVO> reviewContentBudgetList = new ArrayList<>(); // 投标文件评审-评审内容-预算负责人实体
	private List<ReviewContentFinanceVO> reviewContentFinanceList = new ArrayList<>(); // 投标文件评审-评审内容-财务负责人实体
	private List<ReviewContentDirectVO> reviewContentDirectList = new ArrayList<>(); // 投标文件评审-评审内容-直管部 （分公司）负责人实体
	private List<ReviewContentBusinessVO> reviewContentBusinessList = new ArrayList<>(); // 投标文件评审-评审内容-经营部负责人实体
	private List<ReviewContentDeputyVO> reviewContentDeputyList = new ArrayList<>(); // 投标文件评审-评审内容-经营副总经理审核意见实体
	private List<ReviewContentGmVO> reviewContentGmList = new ArrayList<>(); // 投标文件评审-评审内容-总经理审批意见实体

	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getDetailedAddress() {
		return detailedAddress;
	}

	public void setDetailedAddress(String detailedAddress) {
		this.detailedAddress = detailedAddress;
	}

	public String getTelFax() {
		return telFax;
	}

	public void setTelFax(String telFax) {
		this.telFax = telFax;
	}

	public BigDecimal getBidPrice() {
		return bidPrice;
	}

	public void setBidPrice(BigDecimal bidPrice) {
		this.bidPrice = bidPrice;
	}

	public Long getStructureId() {
		return structureId;
	}

	@ReferDeserialTransfer
	public void setStructureId(Long structureId) {
		this.structureId = structureId;
	}

	public String getStructureCode() {
		return structureCode;
	}

	public void setStructureCode(String structureCode) {
		this.structureCode = structureCode;
	}

	public String getStructureName() {
		return structureName;
	}

	public void setStructureName(String structureName) {
		this.structureName = structureName;
	}

	public BigDecimal getProjectTotalArea() {
		return projectTotalArea;
	}

	public void setProjectTotalArea(BigDecimal projectTotalArea) {
		this.projectTotalArea = projectTotalArea;
	}

	public Long getContractModeId() {
		return contractModeId;
	}

	@ReferDeserialTransfer
	public void setContractModeId(Long contractModeId) {
		this.contractModeId = contractModeId;
	}

	public String getContractModeCode() {
		return contractModeCode;
	}

	public void setContractModeCode(String contractModeCode) {
		this.contractModeCode = contractModeCode;
	}

	public String getContractModeName() {
		return contractModeName;
	}

	public void setContractModeName(String contractModeName) {
		this.contractModeName = contractModeName;
	}

	public Long getProjectQualityId() {
		return projectQualityId;
	}

	@ReferDeserialTransfer
	public void setProjectQualityId(Long projectQualityId) {
		this.projectQualityId = projectQualityId;
	}

	public String getProjectQualityCode() {
		return projectQualityCode;
	}

	public void setProjectQualityCode(String projectQualityCode) {
		this.projectQualityCode = projectQualityCode;
	}

	public String getProjectQualityName() {
		return projectQualityName;
	}

	public void setProjectQualityName(String projectQualityName) {
		this.projectQualityName = projectQualityName;
	}

	public Integer getProjectDuration() {
		return projectDuration;
	}

	public void setProjectDuration(Integer projectDuration) {
		this.projectDuration = projectDuration;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

	public Long getSourceBidRecordId() {
		return sourceBidRecordId;
	}

	public void setSourceBidRecordId(Long sourceBidRecordId) {
		this.sourceBidRecordId = sourceBidRecordId;
	}

	public String getProjectContentId() {
		return projectContentId;
	}

	@ReferDeserialTransfer
	public void setProjectContentId(String projectContentId) {
		this.projectContentId = projectContentId;
	}

	public String getProjectContentCode() {
		return projectContentCode;
	}

	public void setProjectContentCode(String projectContentCode) {
		this.projectContentCode = projectContentCode;
	}

	public String getProjectContentName() {
		return projectContentName;
	}

	public void setProjectContentName(String projectContentName) {
		this.projectContentName = projectContentName;
	}

	public Integer getBidFlag() {
		return bidFlag;
	}

	public void setBidFlag(Integer bidFlag) {
		this.bidFlag = bidFlag;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<ReviewFundVO> getReviewFundList() {
		return reviewFundList;
	}

	public void setReviewFundList(List<ReviewFundVO> reviewFundList) {
		this.reviewFundList = reviewFundList;
	}

	public List<ReviewContentManageVO> getReviewContentManageList() {
		return reviewContentManageList;
	}

	public void setReviewContentManageList(List<ReviewContentManageVO> reviewContentManageList) {
		this.reviewContentManageList = reviewContentManageList;
	}

	public List<ReviewContentTechnologyVO> getReviewContentTechnologyList() {
		return reviewContentTechnologyList;
	}

	public void setReviewContentTechnologyList(List<ReviewContentTechnologyVO> reviewContentTechnologyList) {
		this.reviewContentTechnologyList = reviewContentTechnologyList;
	}

	public List<ReviewContentBudgetVO> getReviewContentBudgetList() {
		return reviewContentBudgetList;
	}

	public void setReviewContentBudgetList(List<ReviewContentBudgetVO> reviewContentBudgetList) {
		this.reviewContentBudgetList = reviewContentBudgetList;
	}

	public List<ReviewContentFinanceVO> getReviewContentFinanceList() {
		return reviewContentFinanceList;
	}

	public void setReviewContentFinanceList(List<ReviewContentFinanceVO> reviewContentFinanceList) {
		this.reviewContentFinanceList = reviewContentFinanceList;
	}

	public List<ReviewContentDirectVO> getReviewContentDirectList() {
		return reviewContentDirectList;
	}

	public void setReviewContentDirectList(List<ReviewContentDirectVO> reviewContentDirectList) {
		this.reviewContentDirectList = reviewContentDirectList;
	}

	public List<ReviewContentBusinessVO> getReviewContentBusinessList() {
		return reviewContentBusinessList;
	}

	public void setReviewContentBusinessList(List<ReviewContentBusinessVO> reviewContentBusinessList) {
		this.reviewContentBusinessList = reviewContentBusinessList;
	}

	public List<ReviewContentDeputyVO> getReviewContentDeputyList() {
		return reviewContentDeputyList;
	}

	public void setReviewContentDeputyList(List<ReviewContentDeputyVO> reviewContentDeputyList) {
		this.reviewContentDeputyList = reviewContentDeputyList;
	}

	public List<ReviewContentGmVO> getReviewContentGmList() {
		return reviewContentGmList;
	}

	public void setReviewContentGmList(List<ReviewContentGmVO> reviewContentGmList) {
		this.reviewContentGmList = reviewContentGmList;
	}
}
